@@ -1,6 +1,9 @@
 #' @title Two-sample tests
 #' @name two_sample_test
 #'
+#' @description
+#' Parametric, non-parametric, robust, and Bayesian two-sample tests.
+#'
 #' @inheritParams long_to_wide_converter
 #' @inheritParams stats_type_switch
 #' @inheritParams one_sample_test
@@ -8,7 +11,7 @@
 #' @inheritParams stats::t.test
 #' @inheritParams add_expression_col
 #'
-#' @description
+#' @section Two-sample tests:
 #'
 #' ```{r child="man/rmd-fragments/table_intro.Rmd"}
 #' ```
@@ -157,7 +160,6 @@ two_sample_test <- function(data,
   if (type == "nonparametric") c(.f, .f.es) %<-% c(stats::wilcox.test, effectsize::rank_biserial)
 
   if (type %in% c("parametric", "nonparametric")) {
-    # extracting test details
     stats_df <- exec(
       .f,
       formula     = new_formula(y, x),
@@ -167,9 +169,8 @@ two_sample_test <- function(data,
       var.equal   = var.equal,
       exact       = FALSE
     ) %>%
-      tidy_model_parameters(.)
+      tidy_model_parameters()
 
-    # extracting effect size details
     effsize_df <- exec(
       .f.es,
       x           = new_formula(y, x),
@@ -179,7 +180,7 @@ two_sample_test <- function(data,
       ci          = conf.level,
       verbose     = FALSE
     ) %>%
-      tidy_model_effectsize(.)
+      tidy_model_effectsize()
   }
 
   # robust ---------------------------------------
@@ -189,7 +190,6 @@ two_sample_test <- function(data,
     k.df <- ifelse(paired, 0L, k)
 
     # styler: off
-    # which functions to be used for hypothesis testing and estimation?
     if (!paired) c(.f, .f.es) %<-% c(WRS2::yuen, WRS2::akp.effect)
     if (paired) c(.f, .f.es)  %<-% c(WRS2::yuend, WRS2::dep.effect)
     # styler: on
@@ -204,7 +204,7 @@ two_sample_test <- function(data,
     # styler: on
   }
 
-  # combining dataframes
+  # combining data frames
   if (type != "bayes") {
     stats_df <- bind_cols(select(stats_df, -matches("^est|^eff|conf|^ci")), select(effsize_df, -matches("term")))
   }
