@@ -8,16 +8,16 @@ withr::local_options(list(tibble.width = Inf))
 
 # between-subjects ------------------------------
 
+skip_if_not_installed("rstantools")
+
 test_that(
   desc = "bayesian (between-subjects - anova)",
   code = {
-    skip_if(getRversion() < "4.0")
-
     # with NA
     set.seed(123)
     df1 <- suppressWarnings(oneway_anova(
       type     = "bayes",
-      data     = ggplot2::msleep,
+      data     = msleep,
       x        = vore,
       y        = brainwt
     ))
